#
# spec file for package owncloud-client
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           owncloud-client

Version:        2.5.4
Release:        lp151.1.1

Summary:        The ownCloud synchronization client
License:        GPL-2.0-only AND GPL-3.0-only
Group:          Productivity/Networking/Other
Url:            http://owncloud.com
Source0:        owncloudclient-%{version}.tar.xz
Source1:        101-sync-inotify.conf
Source2:        README.source

# PATCH-FIX-UPSTREAM fix position of systray menu https://github.com/owncloud/client/issues/5968
# for all except tumbleweed and ongoing, as the Qt bug is fixed in there.
Patch0:         fix-systray-menu-pos.patch
Patch1:         no_theme_icons.patch

%define cmake_args -DSYSCONF_INSTALL_DIR=%{_sysconfdir}

# Build the dolphin overlays for 42.2 ongoing, SLE and Tumbleweed
%if 0%{?sle_version} > 120100 || %{?suse_version} > 1320
%define build_dolphin_overlays 1
%endif

# The client can be branded, not the case so far
%define has_branding 0

# The minimum required version of qtkeychain, stay with 0.4.0 for now
# to stay compatible with 13.2
%define keychain_version 0.4.0

######################################################################### BuildRequires only below here.

BuildRequires:  cmake >= 2.8.11
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  qtkeychain-qt5-devel >= %{keychain_version}

BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Xml)

%if 0%{?build_dolphin_overlays}
BuildRequires:  kio-devel
%endif

BuildRequires:  libopenssl-devel
BuildRequires:  update-desktop-files

BuildRequires:  sqlite3-devel

BuildRequires:  hicolor-icon-theme

######################################################################### Requires only below here.

Suggests:       %{name}-nautilus
Supplements:    packageand(%{name}:nautilus)
Suggests:       %{name}-nemo

Requires:       %{name}-l10n
Requires:       libowncloudsync0 = %{version}

######################################################################### Obsoletes only below here.

Obsoletes:      libocsync-devel
Obsoletes:      libocsync-devel-doc
Obsoletes:      libocsync-doc
Obsoletes:      libocsync-plugin-owncloud
Obsoletes:      libocsync0

######################################################################### Package Descriptions start here.

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The ownCloud sync client - github.com/owncloud/client

ownCloud client enables you to connect to your private
ownCloud Server. With it you can create folders in your home
directory, and keep the contents of those folders synced with your
ownCloud server. Simply copy a file into the directory and the
ownCloud Client does the rest.

ownCloud gives you anytime and anywhere access to the files you
need, whether through this desktop application, our mobile apps,
the web interface, or other WebDAV clients. With it, you can
easily view and share documents and information in a secure,
flexible and controlled architecture. You can extend ownCloud
with plug-ins from the community, or that you build yourself.

%package -n %{name}-doc
Summary:        Documentation for ownCloud
Group:          Development/Libraries/C and C++
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n %{name}-doc
Documentation for the ownCloud desktop application.

%package -n %{name}-l10n
Summary:        Localization for ownCloud
Group:          Development/Libraries/C and C++
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n %{name}-l10n
Localization files for the ownCloud desktop application.

%package -n libowncloudsync0
Requires:       libqt5keychain1 => %{keychain_version}

Summary:        The ownCloud synchronization library
Group:          Development/Libraries/C and C++

%description -n libowncloudsync0
The ownCloud synchronization library. It implements the ownCloud
sync algorithm that keeps a local directory in sync with the
content on your cloud.

%package -n libowncloudsync-devel
Summary:        Development files for the ownCloud synchronization library
Group:          Development/Libraries/C and C++
Requires:       libowncloudsync0 = %{version}

%description -n libowncloudsync-devel
Development files for the ownCloud synchronization library. It
implements the ownCloud sync algorithm that keeps a local directory
in sync with the content on your cloud.

%package -n %{name}-nautilus
Summary:        Nautilus overlay icons
Group:          Productivity/Networking/Other
Requires:       nautilus
Supplements:    packageand(%{name}:nautilus)
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python-nautilus

%description -n %{name}-nautilus
This package provides overlay icons to visualize the synchronization state
in the Nautilus file manager.

%package -n %{name}-nemo
Summary:        Nemo overlay icons
Group:          Productivity/Networking/Other
Requires:       nemo
Supplements:    packageand(%{name}:nemo)
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python-nemo

%description -n %{name}-nemo
This package provides overlay icons to visualize the synchronization state
in the Nemo file manager.

%package -n %{name}-caja
Summary:        Caja overlay icons
Group:          Productivity/Networking/Other
Requires:       nemo
Supplements:    packageand(%{name}:caja}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       python-caja

%description -n %{name}-caja
This package provides overlay icons to visualize the synchronization state
in the Caja file manager.

%if 0%{?build_dolphin_overlays}
%package -n %{name}-dolphin
Summary:        Dolphin overlay icons
Group:          Productivity/Networking/Other
Requires:       dolphin
Supplements:    packageand(%{name}:dolphin)
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description -n %{name}-dolphin
This package provides the necessary plugin libraries for the KDE
Framework 5 based Dolphin filemanager to display overlay icons.

%endif

%prep
%setup -q -n owncloudclient-%{version}

%if 0%{?suse_version} <= 1500
%patch0 -p1
%endif
%patch1 -p1

%build
echo suse_version   0%{?suse_version}

# http://www.cmake.org/Wiki/CMake_RPATH_handling#Default_RPATH_settings
%cmake .. -DWITH_DOC=TRUE \
  -DKDE_INSTALL_USE_QT_SYS_PATHS=1 \
  -DCMAKE_C_FLAGS:STRING="%{optflags}" \
  -DCMAKE_CXX_FLAGS:STRING="%{optflags}" \
  -DCMAKE_SKIP_RPATH=OFF \
  -DCMAKE_BUILD_TYPE=RelWithDebInfo \
  -DCMAKE_INSTALL_PREFIX=%{_prefix} \
%if %{_lib} == lib64
  -DLIB_SUFFIX=64 \
%endif
%if %{has_branding}
  -DOEM_THEME_DIR=$PWD/../ownCloud/syncclient \
%endif
  %cmake_args

# documentation here?
if [ -e conf.py ];
then
  # for old cmake versions we need to move the conf.py.
  mv conf.py doc/
fi

env LD_RUN_PATH=%{_libdir}/owncloud:%{_libdir}/owncloud make %{?_smp_mflags} VERBOSE=1

%install
%cmake_install

# Copy the source README here to be picked up by doc macro
cp %{SOURCE2} .

if [ -d %{buildroot}%{_mandir}/man1 ]; then
  gzip %{buildroot}%{_mandir}/man1/*.1
fi

%define extdir %{buildroot}%{_datadir}/nautilus-python/extensions
test -f %{extdir}/ownCloud.py  && mv %{extdir}/ownCloud.py  %{extdir}/owncloud.py  || true
test -f %{extdir}/ownCloud.pyo && mv %{extdir}/ownCloud.pyo %{extdir}/owncloud.pyo || true
test -f %{extdir}/ownCloud.pyc && mv %{extdir}/ownCloud.pyc %{extdir}/owncloud.pyc || true

# https://github.com/owncloud/client/issues/4107
install -m 0755 -D %{SOURCE1} %{buildroot}/etc/sysctl.d/101-sync-inotify.conf

%suse_update_desktop_file -n owncloud
# workaround for https://github.com/owncloud/ownbrander/issues/322
for desktop_icon_dir in $RPM_BUILD_ROOT/usr/share/icons/hicolor/*/apps; do
  # copy shortname to executable name, if missing.
  if [ -f $desktop_icon_dir/owncloud.png -a ! -f $desktop_icon_dir/owncloud.png ]; then
    cp $desktop_icon_dir/owncloud.png $desktop_icon_dir/owncloud.png
  fi
done

%post   -n libowncloudsync0 -p /sbin/ldconfig
%postun -n libowncloudsync0 -p /sbin/ldconfig

%post
%icon_theme_cache_post
%desktop_database_post

%postun
%icon_theme_cache_postun
%desktop_database_postun

%files
%defattr(-,root,root,-)
%{_bindir}/owncloud
%{_bindir}/owncloudcmd
%{_datadir}/applications/owncloud.desktop
%{_datadir}/icons/hicolor
%{_datadir}/mime/packages/owncloud.xml
%doc CONTRIBUTING.md COPYING ChangeLog README.md README.source COPYING.documentation

%config /etc/ownCloud
# https://github.com/owncloud/client/issues/4107
%config /etc/sysctl.d/101-sync-inotify.conf

%files -n %{name}-l10n
%defattr(-,root,root,-)
%{_datadir}/owncloud/

%files -n libowncloudsync0
%defattr(-,root,root,-)
%{_libdir}/libowncloudsync.so.*
%{_libdir}/libowncloud_csync.so.*

%files -n libowncloudsync-devel
%defattr(-,root,root,-)
%{_libdir}/libowncloudsync.so
%{_libdir}/libowncloud_csync.so
%{_includedir}/owncloudsync/

%files -n %{name}-nautilus
%defattr(-,root,root,-)
# Fedora also has *.pyc and *.pyo files here.
%{_datadir}/nautilus-python/extensions/syncstate*.py*
%dir %{_datadir}/nautilus-python
%dir %{_datadir}/nautilus-python/extensions/

%files -n %{name}-nemo
%defattr(-,root,root,-)
# Fedora also has *.pyc and *.pyo files here.
%{_datadir}/nemo-python/extensions/syncstate*.py*
%dir %{_datadir}/nemo-python
%dir %{_datadir}/nemo-python/extensions/

%files -n %{name}-caja
%defattr(-,root,root,-)
# Fedora also has *.pyc and *.pyo files here.
%{_datadir}/caja-python/extensions/syncstate*.py*
%dir %{_datadir}/caja-python
%dir %{_datadir}/caja-python/extensions/

%if 0%{?build_dolphin_overlays}
%files -n %{name}-dolphin
%defattr(-,root,root,-)
%{_libdir}/*dolphinpluginhelper.so
%{_libdir}/qt5/plugins/kf5/overlayicon/*dolphinoverlayplugin.so
%{_libdir}/qt5/plugins/*dolphinactionplugin.so

%{_datadir}/kservices5/*dolphinactionplugin.desktop
%dir %{_libdir}/qt5/plugins/kf5/overlayicon
%endif # build_dolphin_overlays

%changelog
* Wed Mar 20 2019 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream release 2.5.4 with various bugfixes
  Details at https://github.com/owncloud/client/releases/tag/v2.5.4
* Thu Feb  7 2019 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream release 2.5.3:
  * Connectivity: Add a noUnauthedRequests branding option
  * Credentials: Warn in log if keychain-write jobs fail (#6776)
  * Database: Move drop-index to after pragmas are set (#6881)
  * Download: Ignore Content-length for compressed HTTP2/SPDY replies (#6885)
* Tue Jan 29 2019 Klaas Freitag <opensuse@freisturz.de>
- Update to upstream version 2.5.2
  Changelog available at https://owncloud.org/changelog/desktop-client/
- Added no_theme_icons.patch to avoid icon mix in the app
* Fri Nov  9 2018 Klaas Freitag <opensuse@freisturz.de>
- update to upstream version 2.5.1
  Changelog available at https://owncloud.org/changelog/desktop-client/
* Tue Sep 18 2018 klaas.freitag@suse.com
- Really removed the rpath.diff file.
* Tue Sep 18 2018 klaas.freitag@suse.com
- update to upstream version 2.5.0
  Changelog available at https://owncloud.org/changelog/desktop-client/
  * Removed patch rpath.diff as not longer required.
  * Added some doc cleanup as the version installs too much.
* Tue Sep  4 2018 klaas.freitag@suse.com
- Fixed patch fix-systray-menu-pos.patch to avoid segfault as
  described in boo#1106103. Should be fixed with this.
* Wed Aug 15 2018 klaas.freitag@suse.com
- Update to upstream version 2.4.3
  * OAuth2: Fix infinite loop when the refresh token is expired
  * Nautilus: Guard against None state (#6643)
* Wed Jul 25 2018 klaas.freitag@suse.com
- Update to upstream version 2.4.2
  * Coming with some bugfixes, Changelog:
    https://owncloud.org/changelog/desktop-client/
- Added patch fix-systray-menu-pos.patch to fix a problem with
  older Qt versions. Applies only to versions Leap 15 and older,
  fixes https://github.com/owncloud/client/issues/5968
* Fri Mar 16 2018 freitag@owncloud.com
- Updated changelog for upstream release.
* Tue Mar  6 2018 klaas.freitag@suse.com
- Update to upstream version 2.4.1
  * Enhanced Nautilus integration.
  * Cleaner User Experience and overall improvements to
    notifications and the synchronization of files.
  * Better implementation and integration of Client Filesystems.
  * Improved Sharing dialogue
  * and a lot more...
  Changelog: https://github.com/owncloud/client/releases
* Wed Feb 28 2018 klaas.freitag@suse.com
- Add explicit BuildRequires on Qt5Sql to fix TW build.
* Mon Jan  1 2018 freitag@owncloud.com
- Removed superflous patch force_qdbus_tray_workaround.patch
* Mon Jan  1 2018 freitag@owncloud.com
- Bring back the doc macro to mark the documentation files.
  Fix building by utilizing the exclude macro.
* Fri Dec 29 2017 freitag@owncloud.com
- Fixed documentation installation by avoiding the %%doc macro.
* Thu Dec 28 2017 freitag@owncloud.com
- Added rpath.diff: Fix the rpath to the private libs of owncloud
  Fixed documentation file list issue
* Wed Dec 27 2017 freitag@owncloud.com
- Feedback from review:
  * Use %%{buildroot} instead of ${RPM_BUILD_ROOT}
  * Leave license- and few other readme files with the main package
* Mon Dec 25 2017 freitag@owncloud.com
- Update to version 2.4.0 with lots of fixes and additions.
  Detailed changelog:
  https://raw.githubusercontent.com/owncloud/client/master/ChangeLog
- Drop force_qdbus_tray_workaround.patch: Problem fixed upstream.
* Sat Oct 21 2017 klaas.freitag@suse.com
- Do not install README.source file as requested in sr
* Tue Sep 12 2017 freitag@opensuse.org
- Install README.source to doc. Make pack checker in Factory happy.
* Fri Sep  8 2017 freitag@opensuse.org
- Reworked the source tarball coming from upstream and removed not
  needed stuff as well as questionable licensed files.
  See https://github.com/owncloud/client/issues/6005 for details
  and README.source which was added and explains that.
* Wed Sep  6 2017 freitag@suse.com
- Added updstream patch force_qdbus_tray_workaround.patch to fix a
  problem with the Qt lib on Leap 42.2 only
* Mon Sep  4 2017 klaas.freitag@suse.com
- Update to upstream version 2.3.3
  * Chunking NG: Don't use old chunking on new DAV endpoint (5855)
  * Selective Sync: Skip excluded folders when reading DB, don't let them show errors (5772)
  * Settings: Make window bigger so Qt version is always visible (5760)
  * Share links: Show warning that public link shares are public (5786)
  * Downloads: Re-trigger folder discovery on HTTP 404 (5799)
  * Notifications: Propagate "Dismiss" as DELETE to server (5922)
  * Overlay Icons: Fix potential hangs on Windows
  * SyncJournalDB: Don't use ._ as filename pattern if that does not work because of SMB storage settings (5844)
  * SyncJournalDB: Log reason for sqlite3 opening errors
  * Windows: Fix a memory leak in FileSystem::longWinPath
  * Switch Linux builds also to Qt 5.6.2 (5470)
  * Stopped maintaining Qt 4 support
  * Linux packaging fixes: install the owncloud-client-nemo, owncloud-client-nautilus, owncloud-client-caja, owncloud-client-dolphin package for sync-state icons and a share-with menu in your file manager.
  * Linux deprecation: Releases after 2.3.3 do not support Fedora 24 or lower, openSUSE Leap 42.1 or lower, Debian 7.0 or lower.
  * 2.4.0 deprecation: We will drop 32-bit Linux support and MacOS X 10.9 support or lower.
  * Supported platforms are documented at Desktop System Requirements.
* Tue Jun 13 2017 klaas.freitag@suse.com
- Fix: Build the dolphin overlays also for Tumbleweed.
* Wed May 10 2017 klaas.freitag@suse.com
- version 2.3.2 (2017-05-08)
  * Fix more crashes (thanks to everyone submitting to our crash reporter!)
  * Improve compatibility with server 10.0 (#5691, X-OC-Total-Size)
  * Share dialog: UI improvements, Bring to front on tray click
  * owncloudcmd: Align process return value with sync return value (#3936)
  * Fix disk free check on Windows when opening the local DB
* Wed May  3 2017 klaas.freitag@suse.com
- Use desktop database update script in postinstall and uninstall
* Fri Apr 28 2017 klaas.freitag@suse.com
- update to version 2.3.2 rc1
  * Fix more crashes (thanks to everyone submitting to our crash reporter!)
  * Improve compatibility with server 10.0 (5691, X-OC-Total-Size)
  * Share dialog: UI improvements, Bring to front on tray click
  * owncloudcmd: Align process return value with sync return value (3936)
* Fri Apr 28 2017 badshah400@gmail.com
- Use full URL for source code.
- Run post-install/uninstall scriptlets for %%{name} to update the
  hicolor icon theme cache, as it installs icons to that theme.
  This fixes an issue where a generic icon instead of the app icon
  showed up in the desktop menus after installation; necessitates
  a BuildRequires on the hicolor-icon-theme, which provides the
  appropriate macros.
* Thu Mar 30 2017 klaas.freitag@suse.com
- fix condition for kde dolphin plugin, do not build on 13.2
* Thu Mar 30 2017 freitag@opensuse.org
  version 2.3.1 (2017-03-2x)
  * Fix several crashes (thanks to everyone submitting to our crash reporter!)
  * Improve HTTP redirect handling (#5555)
  * Blacklist: Escalate repeated soft error to normal error (#5500)
  * NTFS: Do not attempt to upload two existing files with similar casing (#5544)
  * Fix URL for linking to application password generation for ownCloud 10.0 (#5605)
* Fri Mar  3 2017 freitag@opensuse.org
- version 2.3.0 (2017-03-03)
  * Decreased memory usage during sync
  * Overlay icons: Lower CPU usage
  * Allow to not sync the server's external storages by default
  * Switch Windows and OS X build to Qt 5.6.2
  * Switch to new ownCloud server WebDAV endpoint
  * Chunking NG: New file upload chunking algorithmn for ownCloud server 9.2
  * Allow to sync a folder to multiple different servers (Filename change from .csync_journal.db to _sync_$HASH.db)
  * Conflicts: Use the local mtime for the conflict file name (#5273)
  * "Sync now" menu item
  * SSL Client certificate support improved (Show UI, Store keys in keychain)
  * Propagator: Upload more small files in parallel
  * Sync Engine: Read data-fingerprint property to detect backups (#2325)
  * GUI: Show link to ceate an app password/token for syncing
  * Share dialog: Add 'Mail link' button
  * Caja file manager plugin
  * Make "backup detected" message to not trigger in wrong cases
  * SyncEngine: Fix renaming of folder when file are changed (#5192)
  * Fix reconnect bug if status.php intermittently returns wrong data (#5188)
  * Improve sync scheduling (#5317)
  * Overlay icons: Improvements in correctnes
  * Tray menu: Only update on demand to fix Linux desktop integration glitches
  * Progress: Better time/bandwidth estimations
  * Network: Follow certain HTTP redirects (#2791)
  * Network: Remove all cookies (including load balancers etc) when logging out
  * Discovery thread: Low priority
  * owncloudsync.log: Write during propagation
  * Better error message for files with trailing spaces on Windows
  * Excludes: Consider files in hidden folders excluded (#5163)
  * Allow sync directory to be a symlinked directory
  * Add manifest file on Windows to make the application UAC aware
  * macOS: Improve monochrome tray icons
  * Shibboleth bugfixes
  * Fixes with regards to low disk space
  * A ton of other bugfixes
  * Refactorings
  * Improved documentation
  * Crash fixes
* Sat Dec  3 2016 freitag@opensuse.org
- Renamed inotify configuration file to not conflict with nc client
* Fri Dec  2 2016 freitag@opensuse.org
- README file removed from package source dir. Not used.
* Fri Dec  2 2016 freitag@opensuse.org
- Auto-formatted the spec to add a Copyright header
* Fri Dec  2 2016 freitag@opensuse.org
- Removed bogus stuff from changes file and use pkgconfig, following
  suggestions in the pull request.
* Thu Dec  1 2016 freitag@opensuse.org
- Build dolphin plugin only in newer SUSE distros
* Wed Nov 30 2016 freitag@opensuse.org
- More specfile refinements and cleanups.
* Fri Nov 18 2016 freitag@opensuse.org
- Added accidentially removed file again.
* Fri Nov 18 2016 freitag@opensuse.org
- Remove left-over files
* Fri Nov 18 2016 freitag@opensuse.org
- Stripped down to a simple openSUSE-only spec to use it to push the
  client to Tumbleweed.
